==> better-admin-ui-vue-0.0.1.tgz: package/es/components/MixedInput/MixedInput.js <==
import * as _vue from "vue";

/**
 * @Date: 2020/11/23 9:41 下午
 * @Author: Fioanna
 * @Description: 组合输入建议框
 */
import AInput from 'ant-design-vue/es/input';
import ESelect from '../Select';
import ESuggestSelect from '../SuggestSelect';
import mixedInputProps from './types';
var AInputGroup = AInput.Group;
export default {
  name: 'EMixedInput',
  components: {
    AInput: AInput,
    AInputGroup: AInputGroup,
    ESelect: ESelect,
    ESuggestSelect: ESuggestSelect
  },
  props: mixedInputProps,
  data: function data() {
    return {
      // 左边的选项值
      leftOption: {},
      // 双向绑定数据
      dValue: this.$props.value
    };
  },
  model: {
    props: 'value',
    event: 'change'
  },
  computed: {
    placeholder: function placeholder() {
      if (this.$data.leftOption.props && this.$data.leftOption.props.placeholder) {
        return this.$data.leftOption.props.placeholder;
      }

      return '请输入' + this.$data.leftOption.label;
    }
  },
  watch: {
    value: function value(newVal) {
      this.dValue = newVal || undefined;
    },
    dValue: function dValue(newVal) {
      if (this.value !== newVal) {
        // 当前数据和传入的值不同时，改变外面的值
        this.$emit('change', newVal);
      }
    }
  },
  created: function created() {
    if (this.$props.options && this.$props.options[0]) {
      this.$data.leftOption = this.$props.options[0];
    }

    this.$data.dValue = this.$props.value;
  },
  methods: {
    // 左边下拉选项变更
    _leftChange: function _leftChange(value, label, option) {
      if (this.$data.leftOption.value !== value) {
        this.$data.leftOption = option;
        this.dValue = undefined;
        this.$refs.suggestSelect && this.$refs.suggestSelect.resetSuggestList();
      }
    }
  },
  render: function render() {
    var _this = this;

    var _this$$props = this.$props,
        disabled = _this$$props.disabled,
        options = _this$$props.options;
    var _this$$data$leftOptio = this.$data.leftOption,
        suggest = _this$$data$leftOptio.suggest,
        props = _this$$data$leftOptio.props,
        value = _this$$data$leftOptio.value;
    return _vue.createVNode(_vue.resolveComponent("a-input-group"), {
      "compact": true
    }, {
      "default": function _default() {
        return [_vue.createVNode(_vue.resolveComponent("e-select"), {
          "style": "width:40%",
          "options": options,
          "value": value,
          "onChange": _this._leftChange
        }, null), suggest ? _vue.createVNode(_vue.resolveComponent("e-suggest-select"), _vue.mergeProps({
          props: props
        }, {
          "ref": "suggestSelect",
          "style": "width:60%;",
          "placeholder": _this.placeholder,
          "disabled": disabled,
          "modelValue": _this.$data.dValue,
          "onUpdate:modelValue": function onUpdateModelValue($event) {
            return _this.$data.dValue = $event;
          }
        }), null) : _vue.createVNode(_vue.resolveComponent("a-input"), _vue.mergeProps({
          props: props
        }, {
          "style": "width:60%;",
          "placeholder": _this.placeholder,
          "disabled": disabled,
          "modelValue": _this.$data.dValue,
          "onUpdate:modelValue": function onUpdateModelValue($event) {
            return _this.$data.dValue = $event;
          }
        }), null)];
      }
    });
  }
};

==> better-admin-ui-vue-0.0.7.tgz: package/es/components/MixedInput/MixedInput.js <==
import _mergeJSXProps2 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps from "babel-helper-vue-jsx-merge-props";

/**
 * @Date: 2020/11/23 9:41 下午
 * @Author: Fioanna
 * @Description: 组合输入建议框
 */
import AInput from 'ant-design-vue/es/input';
import ESelect from '../Select';
import ESuggestSelect from '../SuggestSelect';
import mixedInputProps from './types';
var AInputGroup = AInput.Group;
export default {
  name: 'EMixedInput',
  props: mixedInputProps,
  data: function data() {
    return {
      // 左边的选项值
      leftOption: {},
      // 双向绑定数据
      dValue: this.$props.value
    };
  },
  model: {
    props: 'value',
    event: 'change'
  },
  computed: {
    placeholder: function placeholder() {
      if (this.$data.leftOption.props && this.$data.leftOption.props.placeholder) {
        return this.$data.leftOption.props.placeholder;
      }

      return '请输入' + this.$data.leftOption.label;
    }
  },
  watch: {
    value: function value(newVal) {
      this.dValue = newVal || undefined;
    },
    dValue: function dValue(newVal) {
      if (this.value !== newVal) {
        // 当前数据和传入的值不同时，改变外面的值
        this.$emit('change', newVal);
      }
    }
  },
  created: function created() {
    if (this.$props.options && this.$props.options[0]) {
      this.$data.leftOption = this.$props.options[0];
    }

    this.$data.dValue = this.$props.value;
  },
  methods: {
    // 左边下拉选项变更
    _leftChange: function _leftChange(value, label, option) {
      if (this.$data.leftOption.value !== value) {
        this.$data.leftOption = option;
        this.dValue = undefined;
        this.$refs.suggestSelect && this.$refs.suggestSelect.resetSuggestList();
      }
    }
  },
  render: function render() {
    var h = arguments[0];
    var _this$$props = this.$props,
        disabled = _this$$props.disabled,
        options = _this$$props.options;
    var _this$$data$leftOptio = this.$data.leftOption,
        suggest = _this$$data$leftOptio.suggest,
        props = _this$$data$leftOptio.props,
        value = _this$$data$leftOptio.value;
    return h(AInputGroup, {
      attrs: {
        compact: true
      }
    }, [h(ESelect, {
      style: "width:40%",
      attrs: {
        options: options,
        value: value
      },
      on: {
        "change": this._leftChange
      }
    }), suggest ? h(ESuggestSelect, _mergeJSXProps([{
      ref: "suggestSelect",
      style: "width:60%;",
      attrs: {
        placeholder: this.placeholder,
        disabled: disabled
      },
      directives: [{
        name: "model",
        value: this.$data.dValue
      }]
    }, {
      props: props
    }])) : h(AInput, _mergeJSXProps2([{
      style: "width:60%;",
      attrs: {
        placeholder: this.placeholder,
        disabled: disabled
      },
      directives: [{
        name: "model",
        value: this.$data.dValue
      }]
    }, {
      props: props
    }]))]);
  }
};
